@@ -28,7 +28,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlElement.h 1232 2005-10-15 15:56:52Z robux4 $
+	\version \$Id: EbmlElement.h 722 2011-03-27 16:43:10Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #ifndef LIBEBML_ELEMENT_H
@@ -116,6 +116,12 @@ extern const EbmlSemanticContext Context_EbmlGlobal;
     const EbmlCallbacks x::ClassInfos(x::Create, Id_##x, name, Context_##x); \
     x::x() :EbmlUInteger(defval) {}
 
+#define DEFINE_xxx_SINTEGER_DEF(x,id,idl,parent,name,global,defval) \
+    const EbmlId Id_##x    (id, idl); \
+    const EbmlSemanticContext Context_##x = EbmlSemanticContext(0, NULL, &Context_##parent, global, &EBML_INFO(x)); \
+    const EbmlCallbacks x::ClassInfos(x::Create, Id_##x, name, Context_##x); \
+    x::x() :EbmlSInteger(defval) {}
+
 #define DEFINE_xxx_STRING_DEF(x,id,idl,parent,name,global,defval) \
     const EbmlId Id_##x    (id, idl); \
     const EbmlSemanticContext Context_##x = EbmlSemanticContext(0, NULL, &Context_##parent, global, &EBML_INFO(x)); \
@@ -134,7 +140,7 @@ extern const EbmlSemanticContext Context_EbmlGlobal;
 
 #define DEFINE_xxx_CLASS_ORPHAN(x,id,idl,name,global) \
     const EbmlId Id_##x    (id, idl); \
-    const EbmlSemanticContext Context_##x = EbmlSemanticContext(0, NULL, NULL, global, &EBML_INFO(x)); \
+    const EbmlSemanticContext Context_##x = EbmlSemanticContext(0, NULL, NULL, global, NULL); \
     const EbmlCallbacks x::ClassInfos(x::Create, Id_##x, name, Context_##x); \
 
 #define DEFINE_EBML_CONTEXT(x)                             DEFINE_xxx_CONTEXT(x,*GetEbmlGlobal_Context)
@@ -179,6 +185,17 @@ extern const EbmlSemanticContext Context_EbmlGlobal;
     private: \
 		static const EbmlCallbacks ClassInfos; \
 
+#define EBML_CONCRETE_DUMMY_CLASS(Type) \
+    public: \
+        virtual const EbmlSemanticContext &Context() const {return *static_cast<EbmlSemanticContext*>(NULL);} \
+        virtual const char *DebugName() const {return "DummyElement";} \
+		virtual operator const EbmlId &(); \
+        virtual EbmlElement & CreateElement() const {return Create();} \
+        virtual EbmlElement * Clone() const { return new Type(*this); } \
+		static EbmlElement & Create() {return *(new Type);} \
+        static const EbmlId & ClassId(); \
+		static const EbmlCallbacks ClassInfos; \
+
 
 #define EBML_INFO(ref)             ref::ClassInfo()
 #define EBML_ID(ref)               ref::ClassId()
@@ -213,6 +230,16 @@ extern const EbmlSemanticContext Context_EbmlGlobal;
 		static EbmlElement & Create() {return *(new Type);} \
 		static const EbmlCallbacks ClassInfos; \
 
+#define EBML_CONCRETE_DUMMY_CLASS(Type) \
+    public: \
+		virtual const EbmlCallbacks & Generic() const {return ClassInfos;} \
+		virtual operator const EbmlId &(); \
+        virtual EbmlElement & CreateElement() const {return Create();} \
+        virtual EbmlElement * Clone() const { return new Type(*this); } \
+		static EbmlElement & Create() {return *(new Type);} \
+		static const EbmlCallbacks ClassInfos; \
+
+
 #define EBML_INFO(ref)             ref::ClassInfos
 #define EBML_ID(ref)               ref::ClassInfos.GlobalId
 #define EBML_CLASS_SEMCONTEXT(ref) Context_##ref
@@ -350,12 +377,12 @@ class EBML_DLL_API EbmlElement {
 		int GetSizeLength() const {return SizeLength;}
 
 		static EbmlElement * FindNextElement(IOCallback & DataStream, const EbmlSemanticContext & Context, int & UpperLevel, uint64 MaxDataSize, bool AllowDummyElt, unsigned int MaxLowerLevel = 1);
-		static EbmlElement * FindNextID(IOCallback & DataStream, const EbmlCallbacks & ClassInfos, const uint64 MaxDataSize);
+		static EbmlElement * FindNextID(IOCallback & DataStream, const EbmlCallbacks & ClassInfos, uint64 MaxDataSize);
 
 		/*!
 			\brief find the next element with the same ID
 		*/
-		EbmlElement * FindNext(IOCallback & DataStream, const uint64 MaxDataSize);
+		EbmlElement * FindNext(IOCallback & DataStream, uint64 MaxDataSize);
 
 		EbmlElement * SkipData(EbmlStream & DataStream, const EbmlSemanticContext & Context, EbmlElement * TestReadElt = NULL, bool AllowDummyElt = false);
 
@@ -421,7 +448,7 @@ class EBML_DLL_API EbmlElement {
 		/*!
 			\brief void the content of the element (replace by EbmlVoid)
 		*/
-		uint32 VoidMe(IOCallback & output, bool bWithDefault = false);
+		uint64 VoidMe(IOCallback & output, bool bWithDefault = false);
 
 		bool DefaultISset() const {return DefaultIsSet;}
 		virtual bool IsDefaultValue() const = 0;
@@ -435,6 +462,7 @@ class EBML_DLL_API EbmlElement {
 		bool ValueIsSet() const {return bValueIsSet;}
 
 		inline uint64 GetEndPosition() const {
+			assert(bSizeIsFinite); // we don't know where the end is
 			return SizePosition + CodedSizeLength(Size, SizeLength, bSizeIsFinite) + Size;
 		}
 
