@@ -28,7 +28,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlElement.cpp 708 2011-03-20 17:33:49Z robux4 $
+	\version \$Id: EbmlElement.cpp 796 2011-09-09 04:00:42Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 
@@ -486,6 +486,7 @@ EbmlElement * EbmlElement::SkipData(EbmlStream & DataStream, const EbmlSemanticC
 				Result = DataStream.FindNextElement(Context, bUpperElement, 0xFFFFFFFFL, AllowDummyElt);
 			} else {
 				Result = TestReadElt;
+                TestReadElt = NULL;
 			}
 
 			if (Result != NULL) {
@@ -581,14 +582,14 @@ filepos_t EbmlElement::Render(IOCallback & output, bool bWithDefault, bool bKeep
 		if (!bWithDefault && IsDefaultValue()) {
 			return 0;
 		}
-#if defined(_DEBUG) || defined(DEBUG)
+#if defined(LIBEBML_DEBUG)
 		uint64 SupposedSize = UpdateSize(bWithDefault, bForceRender);
-#endif // _DEBUG
+#endif // LIBEBML_DEBUG
 		filepos_t result = RenderHead(output, bForceRender, bWithDefault, bKeepPosition);
 		uint64 WrittenSize = RenderData(output, bForceRender, bWithDefault);
-#if defined(_DEBUG) || defined(DEBUG)
+#if defined(LIBEBML_DEBUG)
 	if (static_cast<int64>(SupposedSize) != (0-1)) assert(WrittenSize == SupposedSize);
-#endif // DEBUG
+#endif // LIBEBML_DEBUG
 		result += WrittenSize;
 		return result;
 	} catch (std::exception & ex) {
